==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/iotoperationsmq/kotlin/inputs/BrokerAuthenticatorMethodsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.iotoperationsmq.kotlin.inputs

import com.pulumi.azurenative.iotoperationsmq.inputs.BrokerAuthenticatorMethodsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Collection of different CrdAuthenticator methods of Broker Resource. NOTE Enum - Only one method is supported for each entry.
 * @property custom Custom Authentication Method.
 * @property sat Service Account Token Method.
 * @property svid Service Account Token Method.
 * @property usernamePassword UsernamePassword Method.
 * @property x509 X509 Method.
 */
public data class BrokerAuthenticatorMethodsArgs(
    public val custom: Output<BrokerAuthenticatorMethodCustomArgs>? = null,
    public val sat: Output<BrokerAuthenticatorMethodSatArgs>? = null,
    public val svid: Output<BrokerAuthenticatorMethodSvidArgs>? = null,
    public val usernamePassword: Output<BrokerAuthenticatorMethodUsernamePasswordArgs>? = null,
    public val x509: Output<BrokerAuthenticatorMethodX509Args>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.iotoperationsmq.inputs.BrokerAuthenticatorMethodsArgs> {
    override fun toJava():
        com.pulumi.azurenative.iotoperationsmq.inputs.BrokerAuthenticatorMethodsArgs =
        com.pulumi.azurenative.iotoperationsmq.inputs.BrokerAuthenticatorMethodsArgs.builder()
            .custom(custom?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .sat(sat?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .svid(svid?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .usernamePassword(usernamePassword?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .x509(x509?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) })).build()
}

/**
 * Builder for [BrokerAuthenticatorMethodsArgs].
 */
@PulumiTagMarker
public class BrokerAuthenticatorMethodsArgsBuilder internal constructor() {
    private var custom: Output<BrokerAuthenticatorMethodCustomArgs>? = null

    private var sat: Output<BrokerAuthenticatorMethodSatArgs>? = null

    private var svid: Output<BrokerAuthenticatorMethodSvidArgs>? = null

    private var usernamePassword: Output<BrokerAuthenticatorMethodUsernamePasswordArgs>? = null

    private var x509: Output<BrokerAuthenticatorMethodX509Args>? = null

    /**
     * @param value Custom Authentication Method.
     */
    @JvmName("nyikvncbufmlmicq")
    public suspend fun custom(`value`: Output<BrokerAuthenticatorMethodCustomArgs>) {
        this.custom = value
    }

    /**
     * @param value Service Account Token Method.
     */
    @JvmName("ivnspuwwjcmkewvm")
    public suspend fun sat(`value`: Output<BrokerAuthenticatorMethodSatArgs>) {
        this.sat = value
    }

    /**
     * @param value Service Account Token Method.
     */
    @JvmName("oomiantustklikqx")
    public suspend fun svid(`value`: Output<BrokerAuthenticatorMethodSvidArgs>) {
        this.svid = value
    }

    /**
     * @param value UsernamePassword Method.
     */
    @JvmName("kejqmcnjgydmxpmn")
    public suspend
    fun usernamePassword(`value`: Output<BrokerAuthenticatorMethodUsernamePasswordArgs>) {
        this.usernamePassword = value
    }

    /**
     * @param value X509 Method.
     */
    @JvmName("kovjnolgdslpwott")
    public suspend fun x509(`value`: Output<BrokerAuthenticatorMethodX509Args>) {
        this.x509 = value
    }

    /**
     * @param value Custom Authentication Method.
     */
    @JvmName("qokwnssxvadfiwul")
    public suspend fun custom(`value`: BrokerAuthenticatorMethodCustomArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.custom = mapped
    }

    /**
     * @param argument Custom Authentication Method.
     */
    @JvmName("hdkkvnccqappntvb")
    public suspend
    fun custom(argument: suspend BrokerAuthenticatorMethodCustomArgsBuilder.() -> Unit) {
        val toBeMapped = BrokerAuthenticatorMethodCustomArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.custom = mapped
    }

    /**
     * @param value Service Account Token Method.
     */
    @JvmName("pkwoxgyxnorqevjn")
    public suspend fun sat(`value`: BrokerAuthenticatorMethodSatArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sat = mapped
    }

    /**
     * @param argument Service Account Token Method.
     */
    @JvmName("wjkrlrxxhathbbao")
    public suspend fun sat(argument: suspend BrokerAuthenticatorMethodSatArgsBuilder.() -> Unit) {
        val toBeMapped = BrokerAuthenticatorMethodSatArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.sat = mapped
    }

    /**
     * @param value Service Account Token Method.
     */
    @JvmName("ndsckcyxuvnweprv")
    public suspend fun svid(`value`: BrokerAuthenticatorMethodSvidArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.svid = mapped
    }

    /**
     * @param argument Service Account Token Method.
     */
    @JvmName("vpeydjlnwcetefrn")
    public suspend fun svid(argument: suspend BrokerAuthenticatorMethodSvidArgsBuilder.() -> Unit) {
        val toBeMapped = BrokerAuthenticatorMethodSvidArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.svid = mapped
    }

    /**
     * @param value UsernamePassword Method.
     */
    @JvmName("oyslvjrhetwywsat")
    public suspend fun usernamePassword(`value`: BrokerAuthenticatorMethodUsernamePasswordArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.usernamePassword = mapped
    }

    /**
     * @param argument UsernamePassword Method.
     */
    @JvmName("uyioqsansjvcwwyq")
    public suspend
    fun usernamePassword(argument: suspend BrokerAuthenticatorMethodUsernamePasswordArgsBuilder.() -> Unit) {
        val toBeMapped = BrokerAuthenticatorMethodUsernamePasswordArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.usernamePassword = mapped
    }

    /**
     * @param value X509 Method.
     */
    @JvmName("mwafycbsnwtgmenu")
    public suspend fun x509(`value`: BrokerAuthenticatorMethodX509Args?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.x509 = mapped
    }

    /**
     * @param argument X509 Method.
     */
    @JvmName("roauwougmqaklshb")
    public suspend fun x509(argument: suspend BrokerAuthenticatorMethodX509ArgsBuilder.() -> Unit) {
        val toBeMapped = BrokerAuthenticatorMethodX509ArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.x509 = mapped
    }

    internal fun build(): BrokerAuthenticatorMethodsArgs = BrokerAuthenticatorMethodsArgs(
        custom = custom,
        sat = sat,
        svid = svid,
        usernamePassword = usernamePassword,
        x509 = x509,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/iotoperationsmq/kotlin/inputs/BrokerAuthenticatorMethodsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.iotoperationsmq.kotlin.inputs

import com.pulumi.azurenative.iotoperationsmq.inputs.BrokerAuthenticatorMethodsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Collection of different CrdAuthenticator methods of Broker Resource. NOTE Enum - Only one method is supported for each entry.
 * @property custom Custom Authentication Method.
 * @property sat Service Account Token Method.
 * @property svid Service Account Token Method.
 * @property usernamePassword UsernamePassword Method.
 * @property x509 X509 Method.
 */
public data class BrokerAuthenticatorMethodsArgs(
    public val custom: Output<BrokerAuthenticatorMethodCustomArgs>? = null,
    public val sat: Output<BrokerAuthenticatorMethodSatArgs>? = null,
    public val svid: Output<BrokerAuthenticatorMethodSvidArgs>? = null,
    public val usernamePassword: Output<BrokerAuthenticatorMethodUsernamePasswordArgs>? = null,
    public val x509: Output<BrokerAuthenticatorMethodX509Args>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.iotoperationsmq.inputs.BrokerAuthenticatorMethodsArgs> {
    override fun toJava():
        com.pulumi.azurenative.iotoperationsmq.inputs.BrokerAuthenticatorMethodsArgs =
        com.pulumi.azurenative.iotoperationsmq.inputs.BrokerAuthenticatorMethodsArgs.builder()
            .custom(custom?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .sat(sat?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .svid(svid?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .usernamePassword(usernamePassword?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .x509(x509?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) })).build()
}

/**
 * Builder for [BrokerAuthenticatorMethodsArgs].
 */
@PulumiTagMarker
public class BrokerAuthenticatorMethodsArgsBuilder internal constructor() {
    private var custom: Output<BrokerAuthenticatorMethodCustomArgs>? = null

    private var sat: Output<BrokerAuthenticatorMethodSatArgs>? = null

    private var svid: Output<BrokerAuthenticatorMethodSvidArgs>? = null

    private var usernamePassword: Output<BrokerAuthenticatorMethodUsernamePasswordArgs>? = null

    private var x509: Output<BrokerAuthenticatorMethodX509Args>? = null

    /**
     * @param value Custom Authentication Method.
     */
    @JvmName("iheneijmngcoyxiq")
    public suspend fun custom(`value`: Output<BrokerAuthenticatorMethodCustomArgs>) {
        this.custom = value
    }

    /**
     * @param value Service Account Token Method.
     */
    @JvmName("dpaqhysinuebubth")
    public suspend fun sat(`value`: Output<BrokerAuthenticatorMethodSatArgs>) {
        this.sat = value
    }

    /**
     * @param value Service Account Token Method.
     */
    @JvmName("bohfpddtrnmheraw")
    public suspend fun svid(`value`: Output<BrokerAuthenticatorMethodSvidArgs>) {
        this.svid = value
    }

    /**
     * @param value UsernamePassword Method.
     */
    @JvmName("uucxivmpwtdndwqe")
    public suspend
    fun usernamePassword(`value`: Output<BrokerAuthenticatorMethodUsernamePasswordArgs>) {
        this.usernamePassword = value
    }

    /**
     * @param value X509 Method.
     */
    @JvmName("hlwchivgyxgdefvj")
    public suspend fun x509(`value`: Output<BrokerAuthenticatorMethodX509Args>) {
        this.x509 = value
    }

    /**
     * @param value Custom Authentication Method.
     */
    @JvmName("pbixsomyhdmsnnlk")
    public suspend fun custom(`value`: BrokerAuthenticatorMethodCustomArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.custom = mapped
    }

    /**
     * @param argument Custom Authentication Method.
     */
    @JvmName("oupxxkhamnpbwhbc")
    public suspend
    fun custom(argument: suspend BrokerAuthenticatorMethodCustomArgsBuilder.() -> Unit) {
        val toBeMapped = BrokerAuthenticatorMethodCustomArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.custom = mapped
    }

    /**
     * @param value Service Account Token Method.
     */
    @JvmName("buowjjinlibddndg")
    public suspend fun sat(`value`: BrokerAuthenticatorMethodSatArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sat = mapped
    }

    /**
     * @param argument Service Account Token Method.
     */
    @JvmName("gskqhykgnsrgrskr")
    public suspend fun sat(argument: suspend BrokerAuthenticatorMethodSatArgsBuilder.() -> Unit) {
        val toBeMapped = BrokerAuthenticatorMethodSatArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.sat = mapped
    }

    /**
     * @param value Service Account Token Method.
     */
    @JvmName("whvhkbupdxkletdm")
    public suspend fun svid(`value`: BrokerAuthenticatorMethodSvidArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.svid = mapped
    }

    /**
     * @param argument Service Account Token Method.
     */
    @JvmName("tksbdavcsshbgsvx")
    public suspend fun svid(argument: suspend BrokerAuthenticatorMethodSvidArgsBuilder.() -> Unit) {
        val toBeMapped = BrokerAuthenticatorMethodSvidArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.svid = mapped
    }

    /**
     * @param value UsernamePassword Method.
     */
    @JvmName("rfpvabfnbuwdpdpq")
    public suspend fun usernamePassword(`value`: BrokerAuthenticatorMethodUsernamePasswordArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.usernamePassword = mapped
    }

    /**
     * @param argument UsernamePassword Method.
     */
    @JvmName("wwhlihypwixxokwm")
    public suspend
    fun usernamePassword(argument: suspend BrokerAuthenticatorMethodUsernamePasswordArgsBuilder.() -> Unit) {
        val toBeMapped = BrokerAuthenticatorMethodUsernamePasswordArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.usernamePassword = mapped
    }

    /**
     * @param value X509 Method.
     */
    @JvmName("basljmgppqubcprs")
    public suspend fun x509(`value`: BrokerAuthenticatorMethodX509Args?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.x509 = mapped
    }

    /**
     * @param argument X509 Method.
     */
    @JvmName("mairyjmlebwflvda")
    public suspend fun x509(argument: suspend BrokerAuthenticatorMethodX509ArgsBuilder.() -> Unit) {
        val toBeMapped = BrokerAuthenticatorMethodX509ArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.x509 = mapped
    }

    internal fun build(): BrokerAuthenticatorMethodsArgs = BrokerAuthenticatorMethodsArgs(
        custom = custom,
        sat = sat,
        svid = svid,
        usernamePassword = usernamePassword,
        x509 = x509,
    )
}
